#!/usr/bin/env bash

file_env() {
	# 3wc: Load $VAR_FILE into $VAR - useful for secrets. See
	# 	https://medium.com/@adrian.gheorghe.dev/using-docker-secrets-in-your-environment-variables-7a0609659aab
	local var="$1"
	local fileVar="${var}_FILE"
	local def="${2:-}"

	if [ "${!var:-}" ] && [ "${!fileVar:-}" ]; then
		echo >&2 "error: both $var and $fileVar are set (but are exclusive)"
		exit 1
	fi
	local val="$def"
	if [ "${!var:-}" ]; then
		val="${!var}"
	elif [ "${!fileVar:-}" ]; then
		val="$(< "${!fileVar}")"
	fi
	export "$var"="$val"
	unset "$fileVar"
}

file_env "DEVISE_SECRET"
file_env "SECRET_COOKIE_TOKEN"
file_env "POSTGRES_PASSWORD"
file_env "SMTP_PASSWORD"
export DATABASE_URL="postgresql://${POSTGRES_USER}:${POSTGRES_PASSWORD}@db/${POSTGRES_DB}"

if [ -n "$1" ]; then
	echo "Running '$1'"
	$1
else
	if [ ! -f /loomio/storage/migrations_ran ] && [ "${TASK:-}" = "worker" ]; then
		echo "first deploy, running DB setup..."
		rake db:setup
		touch /loomio/storage/migrations_ran
	fi

	echo "running DB migrations..."
	rake db:migrate
	echo "DB migrations finished"

	echo "starting loomio!"
	/loomio/docker_start.sh
fi
